@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: config.c,v 1.44 2001/05/17 09:30:52 veillard Exp $
+ * $Id: config.c,v 1.45 2005/03/16 20:13:10 hany Exp $
  */
 
 #include <config.h>
@@ -58,6 +58,7 @@ int  rpm2html_size = 0;
 int  rpm2html_no_sql = 0;
 int  rpm2html_install_files = 0;
 int  rpm2html_install_size = 0;
+int  rpm2html_protect_emails = 0;
 
 char *rpm2html_headers_name[MAX_EXTRA_HEADERS];
 char *rpm2html_headers_url[MAX_EXTRA_HEADERS];
@@ -325,6 +326,17 @@ void addConfigEntry(char *rpmdir, char *name, char *value) {
 		printf("Config file : %s global entry ignored,\n", name);
 		printf("\tuse \"html=true\" or \"html=false\"\n");
 	    }
+	} else if (!strcasecmp(name, "protectemails")) {
+	    if ((!strcasecmp(value, "true")) ||
+	        (!strcasecmp(value, "yes"))) {
+	        rpm2html_protect_emails = 1;
+	    } else if ((!strcasecmp(value, "false")) ||
+	        (!strcasecmp(value, "no"))) {
+	        rpm2html_protect_emails = 0;
+	    } else {
+		printf("Config file : %s global entry ignored,\n", name);
+		printf("\tuse \"protectemails=true\" or \"protectemails=false\"\n");
+	    }
 	} else if (!strcasecmp(name, "header")) {
 	    addHeader(value);
         } else {
