@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: html.c,v 1.114 2002/09/13 08:51:00 veillard Exp $
+ * $Id: html.c,v 1.115 2005/03/08 14:38:28 hany Exp $
  */
 
 #include <config.h>
@@ -565,8 +565,8 @@ void createDirectory(const char *dirname) {
  */
 
 #include <zlib.h>
-#include "dir.gif.h"
-#include "new.gif.h"
+#include "dir.png.h"
+#include "new.png.h"
 
 void dumpDirIcon(void) {
     char path[500];
@@ -577,21 +577,21 @@ void dumpDirIcon(void) {
     if (!rpm2html_dump_html) return;
 
     createDirectory(rpm2html_dir);
-    snprintf(path, sizeof(path), "%s/dir.gif", rpm2html_dir);
-    content = read_data_buffer_dir_gif();
+    snprintf(path, sizeof(path), "%s/dir.png", rpm2html_dir);
+    content = read_data_buffer_dir_png();
     if ((fd = creat(path, 0644)) < 0) {
         fprintf(stderr, "creat() failed on %s\n", path);
 	return;
     }
-    write(fd, content, data_buffer_dir_gif_size);
+    write(fd, content, data_buffer_dir_png_size);
     close(fd);
-    snprintf(path, sizeof(path), "%s/new.gif", rpm2html_dir);
-    content = read_data_buffer_new_gif();
+    snprintf(path, sizeof(path), "%s/new.png", rpm2html_dir);
+    content = read_data_buffer_new_png();
     if ((fd = creat(path, 0644)) < 0) {
         fprintf(stderr, "creat() failed on %s\n", path);
 	return;
     }
-    write(fd, content, data_buffer_new_gif_size);
+    write(fd, content, data_buffer_new_png_size);
     close(fd);
 }
 
@@ -1015,7 +1015,7 @@ void generateHtmlRpmRow(FILE *html, rpmDataPtr cur, int shownew) {
     fprintf(html, "%s</a>", rpmName(cur));
     if ((shownew) && (cur->date > 0) &&
         ((currentTime - cur->date) < (24 * 60 * 60 * 15)))
-	fprintf(html, "<img src=\"%s/new.gif\" alt=\"New\">", rpm2html_url);
+	fprintf(html, "<img src=\"%s/new.png\" alt=\"New\">", rpm2html_url);
     fprintf(html, "</td>\n<td width=\"%d\">%s</td>\n",
             DESCRIPTION_FIELD_WIDTH,
 	    convertHTML(cur->summary));
@@ -1064,7 +1064,7 @@ void generateHtmlRpmArchRow(FILE *html, rpmDataPtr cur) {
 	    generateHtmlRpmAnchor(html, tmp);
 	    fprintf(html, "%s/%s</a>", tmp->os, tmp->arch);
 	    if ((currentTime - tmp->date) < (24 * 60 * 60 * 15))
-		fprintf(html, "<img src=\"%s/new.gif\" alt=\"New\">",
+		fprintf(html, "<img src=\"%s/new.png\" alt=\"New\">",
 		        rpm2html_url);
 	    fprintf(html, "</td>");
 	}
@@ -1181,7 +1181,7 @@ void generateHtmlTree(FILE *html, rpmSubdirPtr tree, int level, int full) {
 			rpm2html_url, localizedStrings[LANG_INDEX_HTML]);
 	    }
 	    fprintf(html,
-	        "<img src=\"%s/dir.gif\" alt=\"parent-directory\" border=0>",
+	        "<img src=\"%s/dir.png\" alt=\"parent-directory\" border=0>",
 	            rpm2html_url);
 	    fprintf(html, " ..</a></strong></p>\n");
 	}
@@ -1191,7 +1191,7 @@ void generateHtmlTree(FILE *html, rpmSubdirPtr tree, int level, int full) {
 		    rpm2html_url, tree->subdirs[i]->htmlpath,
 		    localizedStrings[LANG_INDEX_HTML]);
 	    fprintf(html,
-	        "<img src=\"%s/dir.gif\" alt=\"sub-directory\" border=0>",
+	        "<img src=\"%s/dir.png\" alt=\"sub-directory\" border=0>",
 	            rpm2html_url);
 	    fprintf(html, " %s</a></strong></p>\n", tree->subdirs[i]->name);
 	    if (full)
@@ -1415,7 +1415,7 @@ void dumpTopIndex(rpmDirPtr *sqlDirList) {
 		    continue;
 
 		fprintf(html,
-"<p><strong><a href=\"%s/%s/index.html\"><img src=\"/linux/RPM/dir.gif\" alt=\"sub-directory\" border=0>%s</a></strong></p>\n",
+"<p><strong><a href=\"%s/%s/index.html\"><img src=\"/linux/RPM/dir.png\" alt=\"sub-directory\" border=0>%s</a></strong></p>\n",
                         sqlDirList[i]->url, sqlDirList[i]->subdir,
 			sqlDirList[i]->name);
 
@@ -2847,7 +2847,7 @@ rpmDataPtr dumpDirIndex(rpmDirPtr dir, rpmSubdirPtr tree, rpmDataPtr list) {
 	fprintf(html, "<p><strong><a href=\"%s\">",
 	        localizedStrings[LANG_TREE_HTML]);
 	fprintf(html,
-	        "<img src=\"%s/dir.gif\" alt=\"Directory\" border=0>",
+	        "<img src=\"%s/dir.png\" alt=\"Directory\" border=0>",
 	            rpm2html_url);
 	fprintf(html, " ..</a></strong></p></blockquote>\n");
     }
@@ -2997,7 +2997,7 @@ void rpmDumpHtmlRealTree(FILE *html, rpmDirPtr dir, rpmRealDirPtr tree,
 	            buffer, tree->names[i],
 		    localizedStrings[LANG_TREE_HTML]);
 	    fprintf(subdir,
-	        "<img src=\"%s/dir.gif\" alt=\"subdir\" border=0>",
+	        "<img src=\"%s/dir.png\" alt=\"subdir\" border=0>",
 	            rpm2html_url);
 	    fprintf(subdir, " %s</a>\n", tree->names[i]);
 
