@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.108 2003/12/16 16:54:55 bellet Exp $
+ * $Id: rpmopen.c,v 1.112 2005/03/16 20:13:10 hany Exp $
  */
 
 #include <config.h>
@@ -557,7 +557,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
         (type != RPM_STRING_TYPE)) {
         rpm->vendor = NULL;
     } else {
-        rpm->vendor = stringAdd((char *) p);
+        rpm->vendor = stringAdd(protectEmail((char *) p));
     }
     ENTRY_CLEANUP(p);
     if (!headerGetEntry(h, RPMTAG_GROUP, &type, &p, &count) || !p ||
@@ -637,7 +637,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
         (type != RPM_STRING_TYPE)) {
         rpm->extra->packager = NULL;
     } else {
-        rpm->extra->packager = xmlStrdup((char *) p);
+        rpm->extra->packager = xmlStrdup(protectEmail((char *) p));
     }
     ENTRY_CLEANUP(p);
     if (!headerGetEntry(h, RPMTAG_COPYRIGHT, &type, &p, &count) || !p ||
@@ -651,7 +651,8 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
     if (!headerGetEntry(h, RPMTAG_CHANGELOGTEXT, &type, &p, &count) || !p) {
         rpm->extra->changelog = NULL;
     } else {
-        time_t *dates;
+        int_32 *dates;	/* necessary when sizeof(time_t) != sizeof(int_32) */
+        time_t date;
         char **names;
         char **holdp = (char **) p;
         char *cp;
@@ -680,7 +681,8 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
                 }
                 res = &buffer[delta];
             }
-            tm_buf = localtime(&dates[i]);
+            date = dates[i];
+            tm_buf = localtime(&date);
             strftime(date_string, sizeof(date_string) - 1, "%a %b %d %Y",
                      tm_buf);
             len =
@@ -701,7 +703,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
             *res++ = '\n';
         }
         *res = '\0';
-        rpm->extra->changelog = xmlStrdup(buffer);
+        rpm->extra->changelog = xmlStrdup(protectEmail(buffer));
     }
     ENTRY_CLEANUP(p);
     if (rpm->vendor == NULL) {
@@ -865,9 +867,12 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
     const char *fname;
     rpmfi fi;
     fi = rpmfiNew(NULL, h, RPMTAG_BASENAMES, 0);
-    fi = rpmfiInit(fi, 0);
-    rpm->extra->filelist = NULL;	/* No filelist in the package ! */
-    char *ptr = buffer;
+
+    if (rpmfiFC(fi) <= 0)
+	rpm->extra->filelist = NULL;	/* No filelist in the package ! */
+    else {
+    	fi = rpmfiInit(fi, 0);
+    	char *ptr = buffer;
 
         while (rpmfiNext(fi) >= 0) {
             fname = rpmfiFN(fi);
@@ -908,8 +913,8 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
         fi = rpmfiFree(fi);
 #endif
         rpm->extra->filelist = xmlStrdup(buffer);
-#ifndef HAVE_RPM42
     }
+#ifndef HAVE_RPM42
     ENTRY_CLEANUP(p);
 #endif
 
